@@ -30,6 +30,7 @@ from astropy.table import Table
 from astropy.time import Time
 from datetime import datetime
 import toasty
+from toasty import TilingMethod
 
 from traitlets import HasTraits, validate, observe
 from .traits import Color, Bool, Float, Unicode, AstropyQuantity, Any, to_hex
@@ -244,8 +245,7 @@ class LayerManager(object):
         hdu_index=None,
         verbose=True,
         name=None,
-        force_hipsgen=False,
-        force_tan=False,
+        tiling_method=TilingMethod.AUTO_DETECT,
         **kwargs
     ):
         """
@@ -260,7 +260,8 @@ class LayerManager(object):
         image : str or list of str or :class:`~astropy.io.fits.ImageHDU` or tuple
             The image to show, which should be given either as a filename,
             a list of FITS file paths, an :class:`~astropy.io.fits.ImageHDU`
-            object, or a tuple of the form ``(array, wcs)`` where ``array`` is
+            object, an :class:`~astropy.io.fits.HDUList`, or a tuple of the form
+            ``(array, wcs)`` where ``array`` is
             a Numpy array and ``wcs`` is an astropy :class:`~astropy.wcs.WCS`
             object
         hdu_index : optional int or list of int, defaults to None
@@ -276,22 +277,15 @@ class LayerManager(object):
             Use this parameter to set a display name for the image set.
             If not set, pywwt will set a name based on the file name of the
             provided image.
-        force_hipsgen : optional boolean, defaults to False
-            Force the input FITS to be tiled with HiPSgen. If this and
-            *force_tan* are set to False, this method will figure out when to
-            split the input into tiles and also which type of projection to
-            use. Tangential projection for smaller angular areas and HiPSgen
-            larger regions of the sky.
-        force_tan : optional boolean, defaults to False
-            Force the input FITS to be tiled with a tangential projection. If
-            this and *force_hipsgen* are set to False, this method will figure
-            out when to split the input into tiles and also which type of
-            projection to use. Tangential projection for smaller angular areas
-            and HiPSgen larger regions of the sky.
+        tiling_method : optional :class:`~toasty.TilingMethod`
+            Can be used to force a specific tiling method, i.e. tiled
+            tangential projection, TOAST, HiPS, or even untiled. Defaults
+            to auto-detection, which choses the most appropriate method.
         kwargs
             Additional keyword arguments can be used to set properties on the
             image layer or settings for the `toasty` tiling process. Common
-            toasty settings include ``out_dir``, ``override``, and ``blankval``.
+            toasty settings include ``out_dir``, ``override``, ``blankval``,
+            and ``start``.
             See `toasty.tile_fits`.
 
         Returns
@@ -299,48 +293,93 @@ class LayerManager(object):
         layer : :class:`~pywwt.layers.ImageLayer` or a subclass thereof
         """
 
-        if (
-            isinstance(image, astropy.io.fits.ImageHDU)
-            or isinstance(image, astropy.io.fits.PrimaryHDU)
-            or isinstance(image, astropy.io.fits.HDUList)
+        if isinstance(image, tuple):
+            image, wcs = image
+            image = astropy.io.fits.PrimaryHDU(image, wcs.to_header())
+
+        # For FITS-y inputs, we create a stable filename to allow caching, which
+        # can help to skip expensive processing inside Toasty in case this image
+        # has previously been processed. As usual, the logic is a bit
+        # complicated since we aim to allow the user to give us just about
+        # anything as an input.
+
+        if isinstance(image, astropy.io.fits.HDUList):
+            if hdu_index:
+                image = image[hdu_index]  # delegate to the next stanza
+            else:
+                # NOTE: this is repeating `utils.sanitize_image()`. We do *not*
+                # delegate to the next stanza in case Toasty can do something
+                # with the full HDU list that is better than just picking one
+                # HDU -- so we must write out the full HDUList to disk, not just
+                # the first/best image HDU. That being said, we try to make it
+                # so that the cache key for `HDUList([hdu])` is the same as the
+                # cache key for `hdu`.
+                from hashlib import md5
+
+                m = md5()
+
+                for hdu in image:
+                    if (
+                        hasattr(hdu, "shape")
+                        and len(hdu.shape) > 1
+                        and not isinstance(hdu, astropy.io.fits.BinTableHDU)
+                    ):
+                        # We could `break` here, but it seems safer not to? And
+                        # the performance impact should be minimal.
+                        m.update(hdu.data[:65536])
+                        m.update(hdu.header.tostring().encode("utf-8"))
+
+                hex_string = m.hexdigest()
+                filename = "toasty_input_{}.fits".format(hex_string)
+
+                if not Path(filename).is_file():
+                    image.writeto(filename)
+
+                image = filename
+
+        if isinstance(image, astropy.io.fits.ImageHDU) or isinstance(
+            image, astropy.io.fits.PrimaryHDU
         ):
-            unused_file_name = self._get_unused_fits_name()
-            image.writeto(unused_file_name)
-            image = unused_file_name
+            from hashlib import md5
+
+            m = md5()
+            m.update(image.data[:65536])
+            m.update(image.header.tostring().encode("utf-8"))
+            hex_string = m.hexdigest()
+            filename = "toasty_input_{}.fits".format(hex_string)
+
+            if not Path(filename).is_file():
+                image.writeto(filename)
+
+            image = filename
+
         if isinstance(image, str):
             image = [image]
-        if isinstance(image, list):
-            force_untiled = False
-            if "force_untiled" in kwargs:
-                force_untiled = kwargs["force_untiled"]
-                kwargs.pop("force_untiled", None)
-            if not force_untiled and (
-                force_hipsgen
-                or force_tan
-                or len(image) > 1
-                or Path(image[0]).stat().st_size > 20e6
-            ):  # 20 MB
-                nest_asyncio.apply()
-                loop = asyncio.get_event_loop()
-                return loop.run_until_complete(
-                    self._tile_and_serve(
-                        fits_list=image,
-                        hdu_index=hdu_index,
-                        cli_progress=verbose,
-                        display_name=name,
-                        force_hipsgen=force_hipsgen,
-                        force_tan=force_tan,
-                        **kwargs
-                    )
-                )
-            else:
-                return self._create_and_add_image_layer(
-                    image=image[0], hdu_index=hdu_index, name=name, **kwargs
-                )
 
-        return self._create_and_add_image_layer(
-            image=image, hdu_index=hdu_index, name=name, **kwargs
-        )
+        if (
+            tiling_method == TilingMethod.TOAST
+            or tiling_method == TilingMethod.HIPS
+            or tiling_method == TilingMethod.TAN
+        ) or (
+            tiling_method == TilingMethod.AUTO_DETECT
+            and (len(image) > 1 or Path(image[0]).stat().st_size > 20e6)
+        ):  # 20 MB
+            nest_asyncio.apply()
+            loop = asyncio.get_event_loop()
+            return loop.run_until_complete(
+                self._tile_and_serve(
+                    fits_list=image,
+                    hdu_index=hdu_index,
+                    cli_progress=verbose,
+                    display_name=name,
+                    tiling_method=tiling_method,
+                    **kwargs
+                )
+            )
+        else:
+            return self._create_and_add_image_layer(
+                image=image[0], hdu_index=hdu_index, name=name, **kwargs
+            )
 
     def _create_and_add_image_layer(self, image, **kwargs):
         kwargs = self._remove_toasty_keywords(**kwargs)
@@ -373,22 +412,16 @@ class LayerManager(object):
         kwargs.pop("blankval", None)
         kwargs.pop("override", None)
         kwargs.pop("out_dir", None)
+        kwargs.pop("start", None)
         return kwargs
 
-    def _get_unused_fits_name(self):
-        file_index = 1
-        while Path("hdu_fits_{}".format(file_index)).is_file():
-            file_index += 1
-        return "hdu_fits_{}".format(file_index)
-
     async def _tile_and_serve(
         self,
         fits_list,
         hdu_index=None,
         cli_progress=True,
         display_name=None,
-        force_hipsgen=False,
-        force_tan=False,
+        tiling_method=TilingMethod.AUTO_DETECT,
         **kwargs
     ):
         with warnings.catch_warnings():
@@ -398,8 +431,7 @@ class LayerManager(object):
                 fits_list,
                 hdu_index=hdu_index,
                 cli_progress=cli_progress,
-                force_hipsgen=force_hipsgen,
-                force_tan=force_tan,
+                tiling_method=tiling_method,
                 **kwargs
             )
 
@@ -523,7 +555,7 @@ class LayerManager(object):
         Deprecated, use ``add_table_layer`` instead.
         """
         warnings.warn(
-            "add_data_layer has been deprecated, use " "add_table_layer instead",
+            "add_data_layer has been deprecated, use add_table_layer instead",
             DeprecationWarning,
         )
         return self.add_table_layer(*args, **kwargs)
@@ -598,43 +630,43 @@ class TableLayer(HasTraits):
 
     # Attributes for spherical coordinates
 
-    lon_att = Unicode(help="The column to use for the longitude " "(`str`)").tag(
+    lon_att = Unicode(help="The column to use for the longitude (`str`)").tag(
         wwt="lngColumn"
     )
     lon_unit = Any(
-        help="The units to use for longitude " "(:class:`~astropy.units.Unit`)"
+        help="The units to use for longitude (:class:`~astropy.units.Unit`)"
     ).tag(wwt="raUnits")
-    lat_att = Unicode(help="The column to use for the latitude " "(`str`)").tag(
+    lat_att = Unicode(help="The column to use for the latitude (`str`)").tag(
         wwt="latColumn"
     )
 
-    alt_att = Unicode(help="The column to use for the altitude " "(`str`)").tag(
+    alt_att = Unicode(help="The column to use for the altitude (`str`)").tag(
         wwt="altColumn"
     )
     alt_unit = Any(
-        help="The units to use for the altitude " "(:class:`~astropy.units.Unit`)"
+        help="The units to use for the altitude (:class:`~astropy.units.Unit`)"
     ).tag(wwt="altUnit")
     alt_type = Unicode(help="The type of altitude (`str`)").tag(wwt="altType")
 
     # Attributes for cartesian coordinates
 
-    x_att = Unicode(help="The column to use for the x " "coordinate").tag(
+    x_att = Unicode(help="The column to use for the x coordinate").tag(
         wwt="xAxisColumn"
     )
-    y_att = Unicode(help="The column to use for the y " "coordinate").tag(
+    y_att = Unicode(help="The column to use for the y coordinate").tag(
         wwt="yAxisColumn"
     )
-    z_att = Unicode(help="The column to use for the z " "coordinate").tag(
+    z_att = Unicode(help="The column to use for the z coordinate").tag(
         wwt="zAxisColumn"
     )
-    xyz_unit = Any(help="The units to use for the x/y/z " "positions").tag(
+    xyz_unit = Any(help="The units to use for the x/y/z positions").tag(
         wwt="cartesianScale"
     )
 
     # NOTE: we deliberately don't link size_att to sizeColumn because we need
     # to compute the sizes ourselves based on the min/max and then use the
     # resulting column.
-    size_att = Unicode(help="The column to use for the marker size " "(`str`)").tag(
+    size_att = Unicode(help="The column to use for the marker size (`str`)").tag(
         wwt=None
     )
     size_vmin = Float(
@@ -652,9 +684,7 @@ class TableLayer(HasTraits):
         allow_none=True,
     ).tag(wwt=None)
 
-    cmap_att = Unicode(help="The column to use for the colormap " "(`str`)").tag(
-        wwt=None
-    )
+    cmap_att = Unicode(help="The column to use for the colormap (`str`)").tag(wwt=None)
     cmap_vmin = Float(
         None,
         help="The minimum level of the colormap. Found "
@@ -669,25 +699,25 @@ class TableLayer(HasTraits):
     ).tag(wwt=None)
     cmap = Any(
         cm.viridis,
-        help="The Matplotlib colormap " "(:class:`matplotlib.colors.ListedColormap`)",
+        help="The Matplotlib colormap (:class:`matplotlib.colors.ListedColormap`)",
     ).tag(wwt=None)
 
     # Visual attributes
 
     size_scale = Float(
-        10, help="The factor by which to scale the size " "of the points (`float`)"
+        10, help="The factor by which to scale the size of the points (`float`)"
     ).tag(wwt="scaleFactor")
-    color = Color("white", help="The color of the markers " "(`str` or `tuple`)").tag(
+    color = Color("white", help="The color of the markers (`str` or `tuple`)").tag(
         wwt="color"
     )
-    opacity = Float(1, help="The opacity of the markers " "(`str`)").tag(wwt="opacity")
+    opacity = Float(1, help="The opacity of the markers (`str`)").tag(wwt="opacity")
 
-    marker_type = Unicode("gaussian", help="The type of marker " "(`str`)").tag(
+    marker_type = Unicode("gaussian", help="The type of marker (`str`)").tag(
         wwt="plotType"
     )
     marker_scale = Unicode(
         "screen",
-        help="Whether the scale is " "defined in world or pixel coordinates " "(`str`)",
+        help="Whether the scale is defined in world or pixel coordinates (`str`)",
     ).tag(wwt="markerScale")
 
     far_side_visible = Bool(
@@ -702,7 +732,7 @@ class TableLayer(HasTraits):
     # passing the result on to WWT
     time_att = Unicode(help="The column to use for time (`str`)").tag(wwt=None)
     time_series = Bool(
-        False, help="Whether the layer contains time series " "elements (`bool`)"
+        False, help="Whether the layer contains time series elements (`bool`)"
     ).tag(wwt="timeSeries")
     time_decay = AstropyQuantity(
         16 * u.day,
@@ -712,6 +742,10 @@ class TableLayer(HasTraits):
         "(:class:`~astropy.units.Quantity`)",
     ).tag(wwt="decay")
 
+    selectable = Bool(
+        True, help="Whether sources in the layer are selectable (`bool`)"
+    ).tag(wwt=None)
+
     # TODO: support:
     # xAxisColumn
     # yAxisColumn
@@ -1220,6 +1254,15 @@ class TableLayer(HasTraits):
             value=TIME_COLUMN_NAME,
         )
 
+    @observe("selectable")
+    def _on_selectable_change(self, changed):
+        if not self.notify_changes:
+            return
+
+        self.parent._send_msg(
+            type="modify_selectability", id=self.id, selectable=changed["new"]
+        )
+
     def _get_table(self):
         return self.table
 
@@ -1319,6 +1362,8 @@ class TableLayer(HasTraits):
             wwt_name = trait.metadata.get("wwt")
             if wwt_name:
                 value = trait.get(self)
+                if wwt_name == "decay" and value is not None:
+                    value = value.to(u.day).value
                 if wwt_name == "raUnits" and value is not None:
                     value = VALID_LON_UNITS[value]
                 elif wwt_name == "altUnit" and value is not None:
@@ -1491,7 +1536,7 @@ class ImageLayer(HasTraits):
     opacity = Float(1, help="The opacity of the image").tag(wwt="opacity")
     cmap = Any(
         cm.viridis,
-        help="The Matplotlib colormap " "(:class:`matplotlib.colors.ListedColormap`)",
+        help="The Matplotlib colormap (:class:`matplotlib.colors.ListedColormap`)",
     ).tag(wwt=None)
 
     def __init__(self, parent=None, image=None, url=None, **kwargs):
@@ -1507,14 +1552,14 @@ class ImageLayer(HasTraits):
         self._cmap_version = 0
 
         if image is not None:
-            if "name" in kwargs:
-                self.name = kwargs["name"]
-                kwargs.pop("name", None)
-            elif isinstance(image, str):
-                file_name = image.split("/")[-1].split(".gz")[0]
-                self.name = file_name[: file_name.rfind(".")]
-            else:
-                self.name = self.id
+            self.name = kwargs.pop("name", None)
+
+            if not self.name:
+                if isinstance(image, str):
+                    file_name = path.basename(image).split(".gz")[0]
+                    self.name = file_name[: file_name.rfind(".")]
+                else:
+                    self.name = self.id
 
             # "Classic" mode, processing a single FITS-like input. Transform the
             # image so that it is always acceptable to WWT (Equatorial, TAN
@@ -1547,10 +1592,9 @@ class ImageLayer(HasTraits):
             # Loading image by URL.
             self._sanitized_image = None
             self._image_url = url
-            if "name" in kwargs:
-                self.name = kwargs["name"]
-                kwargs.pop("name", None)
-            else:
+
+            self.name = kwargs.pop("name", None)
+            if not self.name:
                 self.name = url
 
             self.parent._send_msg(
